#ifndef GUI_GNUMERIC_H
#define GUI_GNUMERIC_H

#include "gnumeric.h"

typedef struct _ItemCursor		ItemCursor;
typedef struct _ItemGrid		ItemGrid;
typedef struct _ItemBar			ItemBar;
typedef struct _ItemEdit		ItemEdit;
typedef struct _GnmCanvas		GnmCanvas;
typedef struct _GnumericPane		GnumericPane;
typedef struct _SheetControlGUI		SheetControlGUI;
typedef struct _WorkbookControlComponent  WorkbookControlComponent;
typedef struct _WorkbookControlGUI	  WorkbookControlGUI;
typedef struct _WorkbookControlStandalone WorkbookControlStandalone;

#endif /* GUI_GNUMERIC_H */
